# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpModifyScanConfigSetScannerPreferenceTestMixin:
    def test_modify_scan_config_set_scanner_pref(self):
        self.gmp.modify_scan_config_set_scanner_preference(
            config_id="c1", name="foo"
        )

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1">'
            b"<preference>"
            b"<name>foo</name>"
            b"</preference>"
            b"</modify_config>"
        )

        self.gmp.modify_scan_config_set_scanner_preference("c1", "foo")

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1">'
            b"<preference>"
            b"<name>foo</name>"
            b"</preference>"
            b"</modify_config>"
        )

    def test_modify_scan_config_set_scanner_pref_with_value(self):
        self.gmp.modify_scan_config_set_scanner_preference(
            "c1", "foo", value="bar"
        )

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1">'
            b"<preference>"
            b"<name>foo</name>"
            b"<value>YmFy</value>"
            b"</preference>"
            b"</modify_config>"
        )

    def test_modify_scan_config_scanner_pref_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference(
                "c1", name=None, value="bar"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference(
                "c1", name="", value="bar"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference(
                "c1", "", value="bar"
            )

    def test_modify_scan_config_set_comment_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference(
                config_id=None, name="foo"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference("", "foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_scan_config_set_scanner_preference(
                config_id="", name="foo"
            )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument
from gvm.protocols.gmp.requests.v224 import ReportFormatType


class GmpGetReportFormatTestMixin:
    def test_get_report_format(self):
        self.gmp.get_report_format("rf1")

        self.connection.send.has_been_called_with(
            b'<get_report_formats report_format_id="rf1" details="1"/>'
        )

        self.gmp.get_report_format(report_format_id="rf1")

        self.connection.send.has_been_called_with(
            b'<get_report_formats report_format_id="rf1" details="1"/>'
        )

    def test_get_report_format_missing_report_format_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_report_format(report_format_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_report_format("")

    def test_get_report_format_type(self):
        self.gmp.get_report_format(ReportFormatType.PDF)
        report_format_id = ReportFormatType.from_string("pdf").value
        self.connection.send.has_been_called_with(
            "<get_report_formats "
            f'report_format_id="{report_format_id}" details="1"/>'.encode()
        )

        self.gmp.get_report_format(report_format_id=ReportFormatType.PDF)

        self.connection.send.has_been_called_with(
            "<get_report_formats "
            f'report_format_id="{report_format_id}" details="1"/>'.encode()
        )



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
API wrapper for accessing vulnerability test (VT) metadata from the openvasd HTTP API.
"""

import urllib.parse

import httpx

from ._api import OpenvasdAPI


class VtsAPI(OpenvasdAPI):
    """
    Provides access to the openvasd /vts endpoints.

    This includes retrieving the list of all available vulnerability tests
    as well as fetching detailed information for individual VTs by OID.
    """

    def get_all(self) -> httpx.Response:
        """
        Retrieve the list of all available vulnerability tests (VTs).

        This corresponds to a GET request to `/vts`.

        Returns:
            The full `httpx.Response` containing a JSON list of VT entries.

        Raises:
            httpx.HTTPStatusError: If the server returns a non-success status and exceptions are not suppressed.

        See: GET /vts in the openvasd API documentation.
        """
        try:
            response = self._client.get("/vts")
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def get(self, oid: str) -> httpx.Response:
        """
        Retrieve detailed information about a specific VT by OID.

        This corresponds to a GET request to `/vts/{oid}`.

        Args:
            oid: The OID (object identifier) of the vulnerability test.

        Returns:
            The full `httpx.Response` containing VT metadata for the given OID.

        Raises:
            httpx.HTTPStatusError: If the server returns a non-success status and exceptions are not suppressed.

        See: GET /vts/{id} in the openvasd API documentation.
        """
        quoted_oid = urllib.parse.quote(oid)
        try:
            response = self._client.get(f"/vts/{quoted_oid}")
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v224 import InfoType


class GmpGetInfoListTestMixin:
    def test_get_info_list(self):
        self.gmp.get_info_list(InfoType.CERT_BUND_ADV)

        self.connection.send.has_been_called_with(
            b'<get_info type="CERT_BUND_ADV"/>'
        )

        self.gmp.get_info_list(InfoType.CPE)

        self.connection.send.has_been_called_with(b'<get_info type="CPE"/>')

        self.gmp.get_info_list(info_type=InfoType.CPE)

        self.connection.send.has_been_called_with(b'<get_info type="CPE"/>')

        self.gmp.get_info_list(InfoType.CVE)

        self.connection.send.has_been_called_with(b'<get_info type="CVE"/>')

        self.gmp.get_info_list(InfoType.DFN_CERT_ADV)

        self.connection.send.has_been_called_with(
            b'<get_info type="DFN_CERT_ADV"/>'
        )

        self.gmp.get_info_list(InfoType.OVALDEF)

        self.connection.send.has_been_called_with(b'<get_info type="OVALDEF"/>')

        self.gmp.get_info_list(InfoType.NVT)

        self.connection.send.has_been_called_with(b'<get_info type="NVT"/>')

        with self.assertRaises(AttributeError):
            self.gmp.get_info_list(
                InfoType.ALLINFO  # pylint: disable=no-member
            )

    def test_get_info_list_missing_info_type(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_info_list(info_type=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info_list(info_type="")

        with self.assertRaises(RequiredArgument):
            self.gmp.get_info_list("")

    def test_get_info_list_invalid_info_type(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.get_info_list(info_type="foo")

    def test_get_info_list_with_filter_string(self):
        self.gmp.get_info_list(InfoType.CPE, filter_string="foo=bar")

        self.connection.send.has_been_called_with(
            b'<get_info type="CPE" filter="foo=bar"/>'
        )

    def test_get_info_list_with_filter_id(self):
        self.gmp.get_info_list(info_type=InfoType.CPE, filter_id="f1")

        self.connection.send.has_been_called_with(
            b'<get_info type="CPE" filt_id="f1"/>'
        )

    def test_get_info_list_with_name(self):
        self.gmp.get_info_list(info_type=InfoType.CPE, name="foo")

        self.connection.send.has_been_called_with(
            b'<get_info type="CPE" name="foo"/>'
        )

    def test_get_info_list_with_details(self):
        self.gmp.get_info_list(info_type=InfoType.CPE, details=True)

        self.connection.send.has_been_called_with(
            b'<get_info type="CPE" details="1"/>'
        )

        self.gmp.get_info_list(info_type=InfoType.CPE, details=False)

        self.connection.send.has_been_called_with(
            b'<get_info type="CPE" details="0"/>'
        )



# SPDX-FileCopyrightText: 2020-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpModifyPolicySetCommentTestMixin:
    def test_modify_policy_set_comment(self):
        self.gmp.modify_policy_set_comment("c1")

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1"><comment></comment></modify_config>'
        )

        self.gmp.modify_policy_set_comment("c1", comment="foo")

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1">'
            b"<comment>foo</comment>"
            b"</modify_config>"
        )

        self.gmp.modify_policy_set_comment("c1", comment=None)

        self.connection.send.has_been_called_with(
            b'<modify_config config_id="c1"><comment></comment></modify_config>'
        )

    def test_modify_policy_set_comment_missing_policy_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_comment(policy_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_comment("")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_comment(policy_id="")



# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224 import Gmpv224TestCase
from .feed import GmpGetFeedsTestMixin, GmpGetFeedTestMixin


class Gmpv224GetFeedTestCase(GmpGetFeedTestMixin, Gmpv224TestCase):
    pass


class Gmpv224GetFeedsTestCase(GmpGetFeedsTestMixin, Gmpv224TestCase):
    pass



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.entities.secinfo import (
    GmpGetCertBundListTestMixin,
    GmpGetCertBundTestMixin,
    GmpGetCpeListTestMixin,
    GmpGetCpeTestMixin,
    GmpGetCveListTestMixin,
    GmpGetCveTestMixin,
    GmpGetDfnCertListTestMixin,
    GmpGetDfnCertTestMixin,
    GmpGetInfoListTestMixin,
    GmpGetInfoTestMixin,
    GmpGetNvtFamiliesTestMixin,
    GmpGetNvtListTestMixin,
    GmpGetNvtTestMixin,
    GmpGetScanConfigNvtsTestMixin,
    GmpGetScanConfigNvtTestMixin,
)
from ...gmpv225 import GMPTestCase


class Gmpv225GetCertBundTestCase(GmpGetCertBundTestMixin, GMPTestCase):
    pass


class Gmpv225GetCpeTestCase(GmpGetCpeTestMixin, GMPTestCase):
    pass


class Gmpv225GetCveTestCase(GmpGetCveTestMixin, GMPTestCase):
    pass


class Gmpv225GetDfnCertCase(GmpGetDfnCertTestMixin, GMPTestCase):
    pass


class Gmpv225GetInfoListTestCase(GmpGetInfoListTestMixin, GMPTestCase):
    pass


class Gmpv225GetInfoTestCase(GmpGetInfoTestMixin, GMPTestCase):
    pass


class Gmpv225GetNvtTestCase(GmpGetNvtTestMixin, GMPTestCase):
    pass


class Gmpv225GetScanConfigNvtTestCase(
    GmpGetScanConfigNvtTestMixin, GMPTestCase
):
    pass


class Gmpv225GetNvtFamiliesTestCase(GmpGetNvtFamiliesTestMixin, GMPTestCase):
    pass


class Gmpv225GetScanConfigNvtsTestCase(
    GmpGetScanConfigNvtsTestMixin, GMPTestCase
):
    pass


class Gmpv225GetCertBundListTestCase(GmpGetCertBundListTestMixin, GMPTestCase):
    pass


class Gmpv225GetCpeListTestCase(GmpGetCpeListTestMixin, GMPTestCase):
    pass


class Gmpv225GetCveListTestCase(GmpGetCveListTestMixin, GMPTestCase):
    pass


class Gmpv225GetDfnCertListCase(GmpGetDfnCertListTestMixin, GMPTestCase):
    pass


class Gmpv225GetNvtListTestCase(GmpGetNvtListTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
"""
Module for communication to a daemon speaking `Open Scanner Protocol version 1`_

.. _Open Scanner Protocol version 1:
    https://docs.greenbone.net/API/OSP/osp-20.08.html
"""

import logging
from typing import Any

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.utils import to_bool
from gvm.xml import XmlCommand, XmlCommandElement

from ._protocol import GvmProtocol, T
from .core import Request, Response

logger = logging.getLogger(__name__)

PROTOCOL_VERSION = (1, 2)


def create_credentials_element(
    xml_credentials: XmlCommandElement, credentials: dict[str, dict[str, str]]
):
    """Generates an xml element with credentials."""
    for service, credential in credentials.items():
        cred_type = credential.get("type", "")
        server_port = credential.get("port", "")
        username = credential.get("username")
        password = credential.get("password")

        xml_credential = xml_credentials.add_element("credential")
        xml_credential.set_attribute("type", cred_type)
        xml_credential.set_attribute("port", server_port)
        xml_credential.set_attribute("service", service)

        xml_credential.add_element("username", username)
        xml_credential.add_element("password", password)
    return xml_credentials


def create_vt_selection_element(
    xml_vt_selection: XmlCommandElement, vt_selection: dict[str, Any]
):
    """Generates an xml element with a selection of Vulnerability tests."""
    for vt_id, vt_values in vt_selection.items():
        if vt_id != "vt_groups" and isinstance(vt_values, dict):
            xml_vt = xml_vt_selection.add_element(
                "vt_single", attrs={"id": vt_id}
            )
            if vt_values:
                for key, value in vt_values.items():
                    xml_vt.add_element("vt_value", value, attrs={"id": key})
        elif vt_id == "vt_groups" and isinstance(vt_values, list):
            for group in vt_values:
                xml_vt_selection.add_element(
                    "vt_group", attrs={"filter": group}
                )
        else:
            raise InvalidArgument(
                f"It was not possible to add {vt_id} to the VTs selection."
            )

    return xml_vt_selection


class Osp(GvmProtocol[T]):
    @staticmethod
    def get_protocol_version() -> tuple[int, int]:
        """Determine the Open Scanner Protocol version.

        Returns:
            tuple: Implemented version of the Open Scanner Protocol
        """
        return PROTOCOL_VERSION

    def _send_request(self, cmd: Request) -> Response:
        try:
            return super()._send_request(cmd)
        finally:
            # OSP is stateless. Therefore the connection is closed after each
            # response and we must reset the connection
            self.disconnect()

    def get_version(self) -> T:
        """Get the version of the OSPD server which is connected to."""
        cmd = XmlCommand("get_version")
        return self._send_request_and_transform_response(cmd)

    def help(self) -> T:
        """Get the help text."""
        cmd = XmlCommand("help")
        return self._send_request_and_transform_response(cmd)

    def get_scans(
        self,
        scan_id: str | None = None,
        details: bool = True,
        pop_results: bool = False,
    ) -> T:
        """Get the stored scans.

        Arguments:
            scan_id (str, optional): UUID identifier for a scan.
            details (boolean, optional): Whether to get full scan reports.
                Default: True
            pop_results (boolean, optional) Whether to remove the fetched
                results. Default: False
        """
        cmd = XmlCommand("get_scans")
        if scan_id:
            cmd.set_attribute("scan_id", scan_id)

        cmd.set_attribute("details", to_bool(details))
        cmd.set_attribute("pop_results", to_bool(pop_results))

        return self._send_request_and_transform_response(cmd)

    def delete_scan(self, scan_id: str) -> T:
        """Delete a finished scan.

        Arguments:
            scan_id: UUID identifier for a finished scan.
        """
        if not scan_id:
            raise ValueError("delete_scan requires a scan_id element")

        cmd = XmlCommand("delete_scan")
        cmd.set_attribute("scan_id", scan_id)

        return self._send_request_and_transform_response(cmd)

    def get_scanner_details(self) -> T:
        """Return scanner description and parameters."""
        cmd = XmlCommand("get_scanner_details")
        return self._send_request_and_transform_response(cmd)

    def get_vts(self, vt_id: str | None = None) -> T:
        """Return information about vulnerability tests,
        if offered by scanner.

        Args:
            vt_id: UUID identifier for a vulnerability test.
        """
        cmd = XmlCommand("get_vts")
        if vt_id:
            cmd.set_attribute("vt_id", vt_id)

        return self._send_request_and_transform_response(cmd)

    def start_scan(
        self,
        scan_id: str | None = None,
        parallel: int = 1,
        target=None,
        ports=None,
        targets: list[dict[str, str]] | None = None,
        scanner_params: dict[str, Any] | None = None,
        vt_selection: dict[str, Any] | None = None,
    ) -> T:
        """Start a new scan.

        Args:
            scan_id: UUID identifier for a running scan.
            parallel: Number of parallel scanned targets.
                Default 1.
            target: Deprecated. Please use targets instead.
            targets: List of dictionaries. See example.
            ports: Deprecated. Ports to use for target parameter.
            scanner_params:: Dictionary of scanner parameters.
            vt_selection:: Vulnerability tests to select. See example.

        Examples:

            Scanner Parameters::

                scanner_parameters = {
                    "scan_param1": "scan_param1_value",
                    "scan_param2": "scan_param2_value",
                }

            Targets::

                targets = [
                    {"hosts": "localhost", "ports": "80,43"},
                    {
                        "hosts": "192.168.0.0/24",
                        "ports": "22",
                    },
                    {
                        "credentials": {
                            "smb": {
                                "password": "pass",
                                "port": "port",
                                "type": "type",
                                "username": "username",
                            }
                        }
                    },
                ]

            VT Selection::

                vt_selection = {
                    "vt1": {},
                    "vt2": {"value_id": "value"},
                    "vt_groups": ["family=debian", "family=general"],
                }
        """
        cmd = XmlCommand("start_scan")

        if scan_id:
            cmd.set_attribute("scan_id", scan_id)

        cmd.set_attribute("parallel", str(parallel))

        # Add <scanner_params> even if it is empty, since it is mandatory
        xml_scan_params = cmd.add_element("scanner_params")
        if scanner_params:
            xml_scan_params.set_attributes(scanner_params)

        if targets:
            xml_targets = cmd.add_element("targets")
            for target in targets:
                xml_target = xml_targets.add_element("target")
                hosts = target.get("hosts")
                ports = target.get("ports")
                credentials = target.get("credentials")
                xml_target.add_element("hosts", hosts)
                xml_target.add_element("ports", ports)
                if credentials:
                    create_credentials_element(
                        xml_target.add_element("credentials"), credentials
                    )
        # Check target as attribute for legacy mode compatibility. Deprecated.
        elif target:
            cmd.set_attribute("target", target)
            if ports:
                cmd.set_attribute("ports", ports)
        else:
            raise RequiredArgument(
                function=self.start_scan.__name__, argument="targets"
            )

        if vt_selection:
            create_vt_selection_element(
                cmd.add_element("vt_selection"), vt_selection
            )

        return self._send_request_and_transform_response(cmd)

    def stop_scan(self, scan_id: str) -> T:
        """Stop a currently running scan.

        Args:
            scan_id: UUID identifier for a running scan.
        """
        if not scan_id:
            raise RequiredArgument(
                function=self.stop_scan.__name__, argument="scan_id"
            )

        cmd = XmlCommand("stop_scan")
        cmd.set_attribute("scan_id", scan_id)

        return self._send_request_and_transform_response(cmd)



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

from typing import Optional

from gvm._enum import Enum
from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.core import Request
from gvm.utils import to_bool, to_comma_list
from gvm.xml import XmlCommand

from .._entity_id import EntityID


class AliveTest(Enum):
    """Enum for choosing an alive test"""

    SCAN_CONFIG_DEFAULT = "Scan Config Default"
    ICMP_PING = "ICMP Ping"
    TCP_ACK_SERVICE_PING = "TCP-ACK Service Ping"
    TCP_SYN_SERVICE_PING = "TCP-SYN Service Ping"
    ARP_PING = "ARP Ping"
    APR_PING = "ARP Ping"  # Alias for ARP_PING
    ICMP_AND_TCP_ACK_SERVICE_PING = "ICMP & TCP-ACK Service Ping"
    ICMP_AND_ARP_PING = "ICMP & ARP Ping"
    TCP_ACK_SERVICE_AND_ARP_PING = "TCP-ACK Service & ARP Ping"
    ICMP_TCP_ACK_SERVICE_AND_ARP_PING = (  # pylint: disable=invalid-name
        "ICMP, TCP-ACK Service & ARP Ping"
    )
    CONSIDER_ALIVE = "Consider Alive"

    @classmethod
    def from_string(
        cls,
        alive_test: str | None,
    ) -> Optional["AliveTest"]:
        """Convert an alive test string into a AliveTest instance"""
        if not alive_test:
            return None

        alive_test = alive_test.lower()

        try:
            return cls[
                alive_test.replace(",", "")
                .replace(" ", "_")
                .replace("-", "_")
                .replace("&", "and")
                .upper()
            ]
        except KeyError:
            raise InvalidArgument(
                argument="alive_test",
                function=cls.from_string.__name__,
            ) from None


class Targets:
    @classmethod
    def create_target(
        cls,
        name: str,
        *,
        asset_hosts_filter: str | None = None,
        hosts: list[str] | None = None,
        comment: str | None = None,
        exclude_hosts: list[str] | None = None,
        ssh_credential_id: EntityID | None = None,
        ssh_credential_port: int | str | None = None,
        smb_credential_id: EntityID | None = None,
        esxi_credential_id: EntityID | None = None,
        snmp_credential_id: EntityID | None = None,
        alive_test: str | AliveTest | None = None,
        allow_simultaneous_ips: bool | None = None,
        reverse_lookup_only: bool | None = None,
        reverse_lookup_unify: bool | None = None,
        port_range: str | None = None,
        port_list_id: EntityID | None = None,
    ) -> Request:
        """Create a new target

        Args:
            name: Name of the target
            asset_hosts_filter: Filter to select target host from assets hosts
            hosts: List of hosts addresses to scan
            exclude_hosts: List of hosts addresses to exclude from scan
            comment: Comment for the target
            ssh_credential_id: UUID of a ssh credential to use on target
            ssh_credential_port: The port to use for ssh credential
            smb_credential_id: UUID of a smb credential to use on target
            snmp_credential_id: UUID of a snmp credential to use on target
            esxi_credential_id: UUID of a esxi credential to use on target
            alive_test: Which alive test to use
            allow_simultaneous_ips: Whether to scan multiple IPs of the
                same host simultaneously
            reverse_lookup_only: Whether to scan only hosts that have names
            reverse_lookup_unify: Whether to scan only one IP when multiple IPs
                have the same name.
            port_range: Port range for the target
            port_list_id: UUID of the port list to use on target
        """
        if not name:
            raise RequiredArgument(
                function=cls.create_target.__name__, argument="name"
            )

        cmd = XmlCommand("create_target")
        cmd.add_element("name", name)

        if asset_hosts_filter:
            cmd.add_element(
                "asset_hosts", attrs={"filter": str(asset_hosts_filter)}
            )
        elif hosts:
            cmd.add_element("hosts", to_comma_list(hosts))
        else:
            raise RequiredArgument(
                function=cls.create_target.__name__,
                argument="hosts or asset_hosts_filter",
            )

        if comment:
            cmd.add_element("comment", comment)

        if exclude_hosts:
            cmd.add_element("exclude_hosts", to_comma_list(exclude_hosts))

        if ssh_credential_id:
            xml_ssh = cmd.add_element(
                "ssh_credential", attrs={"id": str(ssh_credential_id)}
            )
            if ssh_credential_port:
                xml_ssh.add_element("port", str(ssh_credential_port))

        if smb_credential_id:
            cmd.add_element(
                "smb_credential", attrs={"id": str(smb_credential_id)}
            )

        if esxi_credential_id:
            cmd.add_element(
                "esxi_credential", attrs={"id": str(esxi_credential_id)}
            )

        if snmp_credential_id:
            cmd.add_element(
                "snmp_credential", attrs={"id": str(snmp_credential_id)}
            )

        if alive_test:
            if not isinstance(alive_test, AliveTest):
                alive_test = AliveTest(alive_test)
            cmd.add_element("alive_tests", alive_test.value)

        if allow_simultaneous_ips is not None:
            cmd.add_element(
                "allow_simultaneous_ips", to_bool(allow_simultaneous_ips)
            )

        if reverse_lookup_only is not None:
            cmd.add_element("reverse_lookup_only", to_bool(reverse_lookup_only))

        if reverse_lookup_unify is not None:
            cmd.add_element(
                "reverse_lookup_unify", to_bool(reverse_lookup_unify)
            )

        if port_range:
            cmd.add_element("port_range", port_range)

        if port_list_id:
            cmd.add_element("port_list", attrs={"id": str(port_list_id)})

        return cmd

    @classmethod
    def modify_target(
        cls,
        target_id: EntityID,
        *,
        name: str | None = None,
        comment: str | None = None,
        hosts: list[str] | None = None,
        exclude_hosts: list[str] | None = None,
        ssh_credential_id: EntityID | None = None,
        ssh_credential_port: str | int | None = None,
        smb_credential_id: EntityID | None = None,
        esxi_credential_id: EntityID | None = None,
        snmp_credential_id: EntityID | None = None,
        alive_test: AliveTest | str | None = None,
        allow_simultaneous_ips: bool | None = None,
        reverse_lookup_only: bool | None = None,
        reverse_lookup_unify: bool | None = None,
        port_list_id: EntityID | None = None,
    ) -> Request:
        """Modify an existing target.

        Args:
            target_id: UUID of target to modify.
            comment: Comment on target.
            name: Name of target.
            hosts: List of target hosts.
            exclude_hosts: A list of hosts to exclude.
            ssh_credential_id: UUID of SSH credential to use on target.
            ssh_credential_port: The port to use for ssh credential
            smb_credential_id: UUID of SMB credential to use on target.
            esxi_credential_id: UUID of ESXi credential to use on target.
            snmp_credential_id: UUID of SNMP credential to use on target.
            port_list_id: UUID of port list describing ports to scan.
            alive_test: Which alive tests to use.
            allow_simultaneous_ips: Whether to scan multiple IPs of the
                same host simultaneously
            reverse_lookup_only: Whether to scan only hosts that have names.
            reverse_lookup_unify: Whether to scan only one IP when multiple IPs
                have the same name.
        """
        if not target_id:
            raise RequiredArgument(
                function=cls.modify_target.__name__, argument="target_id"
            )

        cmd = XmlCommand("modify_target")
        cmd.set_attribute("target_id", str(target_id))

        if comment:
            cmd.add_element("comment", comment)

        if name:
            cmd.add_element("name", name)

        if hosts:
            cmd.add_element("hosts", to_comma_list(hosts))
            if exclude_hosts is None:
                exclude_hosts = [""]

        if exclude_hosts:
            cmd.add_element("exclude_hosts", to_comma_list(exclude_hosts))

        if alive_test:
            if not isinstance(alive_test, AliveTest):
                alive_test = AliveTest(alive_test)
            cmd.add_element("alive_tests", alive_test.value)

        if ssh_credential_id:
            xml_ssh = cmd.add_element(
                "ssh_credential", attrs={"id": str(ssh_credential_id)}
            )

            if ssh_credential_port:
                xml_ssh.add_element("port", str(ssh_credential_port))

        if smb_credential_id:
            cmd.add_element(
                "smb_credential", attrs={"id": str(smb_credential_id)}
            )

        if esxi_credential_id:
            cmd.add_element(
                "esxi_credential", attrs={"id": str(esxi_credential_id)}
            )

        if snmp_credential_id:
            cmd.add_element(
                "snmp_credential", attrs={"id": str(snmp_credential_id)}
            )

        if allow_simultaneous_ips is not None:
            cmd.add_element(
                "allow_simultaneous_ips", to_bool(allow_simultaneous_ips)
            )

        if reverse_lookup_only is not None:
            cmd.add_element("reverse_lookup_only", to_bool(reverse_lookup_only))

        if reverse_lookup_unify is not None:
            cmd.add_element(
                "reverse_lookup_unify", to_bool(reverse_lookup_unify)
            )

        if port_list_id:
            cmd.add_element("port_list", attrs={"id": str(port_list_id)})

        return cmd

    @classmethod
    def clone_target(cls, target_id: EntityID) -> Request:
        """Clone an existing target.

        Args:
            target_id: UUID of an existing target to clone.
        """
        if not target_id:
            raise RequiredArgument(
                function=cls.clone_target.__name__, argument="target_id"
            )

        cmd = XmlCommand("create_target")
        cmd.add_element("copy", str(target_id))
        return cmd

    @classmethod
    def delete_target(
        cls, target_id: EntityID, *, ultimate: bool | None = False
    ) -> Request:
        """Delete an existing target.

        Args:
            target_id: UUID of an existing target to delete.
            ultimate: Whether to remove entirely or to the trashcan.
        """
        if not target_id:
            raise RequiredArgument(
                function=cls.delete_target.__name__, argument="target_id"
            )

        cmd = XmlCommand("delete_target")
        cmd.set_attribute("target_id", str(target_id))
        cmd.set_attribute("ultimate", to_bool(ultimate))
        return cmd

    @classmethod
    def get_target(
        cls, target_id: EntityID, *, tasks: bool | None = None
    ) -> Request:
        """Request a single target.

        Args:
            target_id: UUID of the target to request.
            tasks: Whether to include list of tasks that use the target
        """
        if not target_id:
            raise RequiredArgument(
                function=cls.get_target.__name__, argument="target_id"
            )

        cmd = XmlCommand("get_targets")
        cmd.set_attribute("target_id", str(target_id))

        if tasks is not None:
            cmd.set_attribute("tasks", to_bool(tasks))

        return cmd

    @classmethod
    def get_targets(
        cls,
        *,
        filter_string: str | None = None,
        filter_id: EntityID | None = None,
        trash: bool | None = None,
        tasks: bool | None = None,
    ) -> Request:
        """Request a list of targets.

        Args:
            filter_string: Filter term to use for the query.
            filter_id: UUID of an existing filter to use for the query.
            trash: Whether to include targets in the trashcan.
            tasks: Whether to include list of tasks that use the target.
        """
        cmd = XmlCommand("get_targets")
        cmd.add_filter(filter_string, filter_id)

        if trash is not None:
            cmd.set_attribute("trash", to_bool(trash))

        if tasks is not None:
            cmd.set_attribute("tasks", to_bool(tasks))

        return cmd



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import unittest

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v224 import Permissions, PermissionSubjectType


class PermissionsTestCase(unittest.TestCase):
    def test_clone_permission(self):
        request = Permissions.clone_permission("permission_id")
        self.assertEqual(
            bytes(request),
            b"<create_permission><copy>permission_id</copy></create_permission>",
        )

    def test_clone_permission_missing_permission_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.clone_permission(None)

        with self.assertRaises(RequiredArgument):
            Permissions.clone_permission("")

    def test_create_permission(self):
        request = Permissions.create_permission(
            "name", "subject_id", PermissionSubjectType.USER
        )
        self.assertEqual(
            bytes(request),
            b"<create_permission>"
            b"<name>name</name>"
            b'<subject id="subject_id">'
            b"<type>user</type>"
            b"</subject>"
            b"</create_permission>",
        )

        request = Permissions.create_permission(
            "name",
            "subject_id",
            "user",
        )
        self.assertEqual(
            bytes(request),
            b"<create_permission>"
            b"<name>name</name>"
            b'<subject id="subject_id">'
            b"<type>user</type>"
            b"</subject>"
            b"</create_permission>",
        )

    def test_create_permission_with_resource(self):
        request = Permissions.create_permission(
            "name",
            "subject_id",
            PermissionSubjectType.USER,
            resource_id="resource_id",
            resource_type="alert",
        )
        self.assertEqual(
            bytes(request),
            b"<create_permission>"
            b"<name>name</name>"
            b'<subject id="subject_id">'
            b"<type>user</type>"
            b"</subject>"
            b'<resource id="resource_id">'
            b"<type>alert</type>"
            b"</resource>"
            b"</create_permission>",
        )

    def test_create_permission_with_comment(self):
        request = Permissions.create_permission(
            "name",
            "subject_id",
            PermissionSubjectType.USER,
            comment="comment",
        )
        self.assertEqual(
            bytes(request),
            b"<create_permission>"
            b"<name>name</name>"
            b'<subject id="subject_id">'
            b"<type>user</type>"
            b"</subject>"
            b"<comment>comment</comment>"
            b"</create_permission>",
        )

    def test_create_permission_missing_name(self):
        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                None, "subject_id", PermissionSubjectType.USER
            )

        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                "", "subject_id", PermissionSubjectType.USER
            )

    def test_create_permission_missing_subject_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                "name", None, PermissionSubjectType.USER
            )

        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                "name", "", PermissionSubjectType.USER
            )

    def test_create_permission_with_resource_missing_resource_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                "name",
                "subject_id",
                PermissionSubjectType.USER,
                resource_type="alert",
            )

    def test_create_permission_with_resource_missing_resource_type(self):
        with self.assertRaises(RequiredArgument):
            Permissions.create_permission(
                "name",
                "subject_id",
                PermissionSubjectType.USER,
                resource_id="resource_id",
            )

    def test_create_permission_invalid_subject_type(self):
        with self.assertRaises(InvalidArgument):
            Permissions.create_permission("name", "subject_id", "invalid")

    def test_create_permission_invalid_resource_type(self):
        with self.assertRaises(InvalidArgument):
            Permissions.create_permission(
                "name",
                "subject_id",
                PermissionSubjectType.USER,
                resource_id="resource_id",
                resource_type="invalid",
            )

    def test_delete_permission(self):
        request = Permissions.delete_permission("permission_id")
        self.assertEqual(
            bytes(request),
            b'<delete_permission permission_id="permission_id" ultimate="0"/>',
        )

    def test_delete_permission_ultimate(self):
        request = Permissions.delete_permission("permission_id", ultimate=True)
        self.assertEqual(
            bytes(request),
            b'<delete_permission permission_id="permission_id" ultimate="1"/>',
        )

        request = Permissions.delete_permission("permission_id", ultimate=False)
        self.assertEqual(
            bytes(request),
            b'<delete_permission permission_id="permission_id" ultimate="0"/>',
        )

    def test_delete_permission_missing_permission_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.delete_permission(None)

        with self.assertRaises(RequiredArgument):
            Permissions.delete_permission("")

    def test_get_permissions(self):
        request = Permissions.get_permissions()
        self.assertEqual(
            bytes(request),
            b"<get_permissions/>",
        )

    def test_get_permissions_with_filter_string(self):
        request = Permissions.get_permissions(filter_string="filter_string")
        self.assertEqual(
            bytes(request),
            b'<get_permissions filter="filter_string"/>',
        )

    def test_get_permissions_with_filter_id(self):
        request = Permissions.get_permissions(filter_id="filter_id")
        self.assertEqual(
            bytes(request),
            b'<get_permissions filt_id="filter_id"/>',
        )

    def test_get_permissions_with_trash(self):
        request = Permissions.get_permissions(trash=True)
        self.assertEqual(
            bytes(request),
            b'<get_permissions trash="1"/>',
        )

        request = Permissions.get_permissions(trash=False)
        self.assertEqual(
            bytes(request),
            b'<get_permissions trash="0"/>',
        )

    def test_get_permission(self):
        request = Permissions.get_permission("permission_id")
        self.assertEqual(
            bytes(request),
            b'<get_permissions permission_id="permission_id"/>',
        )

    def test_get_permission_missing_permission_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.get_permission(None)

        with self.assertRaises(RequiredArgument):
            Permissions.get_permission("")

    def test_modify_permission(self):
        request = Permissions.modify_permission("permission_id")
        self.assertEqual(
            bytes(request),
            b'<modify_permission permission_id="permission_id"/>',
        )

    def test_modify_permission_with_name(self):
        request = Permissions.modify_permission("permission_id", name="name")
        self.assertEqual(
            bytes(request),
            b'<modify_permission permission_id="permission_id">'
            b"<name>name</name>"
            b"</modify_permission>",
        )

    def test_modify_permission_with_comment(self):
        request = Permissions.modify_permission(
            "permission_id", comment="comment"
        )
        self.assertEqual(
            bytes(request),
            b'<modify_permission permission_id="permission_id">'
            b"<comment>comment</comment>"
            b"</modify_permission>",
        )

    def test_modify_permission_with_resource(self):
        request = Permissions.modify_permission(
            "permission_id", resource_id="resource_id", resource_type="alert"
        )
        self.assertEqual(
            bytes(request),
            b'<modify_permission permission_id="permission_id">'
            b'<resource id="resource_id">'
            b"<type>alert</type>"
            b"</resource>"
            b"</modify_permission>",
        )

    def test_modify_permission_with_subject(self):
        request = Permissions.modify_permission(
            "permission_id", subject_id="subject_id", subject_type="user"
        )
        self.assertEqual(
            bytes(request),
            b'<modify_permission permission_id="permission_id">'
            b'<subject id="subject_id">'
            b"<type>user</type>"
            b"</subject>"
            b"</modify_permission>",
        )

    def test_modify_permission_with_resource_missing_resource_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.modify_permission(
                "permission_id", resource_type="alert"
            )

    def test_modify_permission_with_resource_missing_resource_type(self):
        with self.assertRaises(RequiredArgument):
            Permissions.modify_permission(
                "permission_id", resource_id="resource_id"
            )

    def test_modify_permission_with_subject_missing_subject_id(self):
        with self.assertRaises(RequiredArgument):
            Permissions.modify_permission("permission_id", subject_type="user")

    def test_modify_permission_with_subject_missing_subject_type(self):
        with self.assertRaises(RequiredArgument):
            Permissions.modify_permission(
                "permission_id", subject_id="subject_id"
            )

    def test_modify_permission_invalid_resource_type(self):
        with self.assertRaises(InvalidArgument):
            Permissions.modify_permission(
                "permission_id",
                resource_id="resource_id",
                resource_type="invalid",
            )

    def test_modify_permission_invalid_subject_type(self):
        with self.assertRaises(InvalidArgument):
            Permissions.modify_permission(
                "permission_id", subject_type="invalid", subject_id="subject_id"
            )



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import socket as socketlib
from os import PathLike, fspath

from gvm.errors import GvmError

from ._connection import DEFAULT_TIMEOUT, AbstractGvmConnection

DEFAULT_UNIX_SOCKET_PATH = "/run/gvmd/gvmd.sock"


class UnixSocketConnection(AbstractGvmConnection):
    """
    UNIX-Socket class to connect, read, write from a daemon via direct
    communicating UNIX-Socket
    """

    def __init__(
        self,
        *,
        path: str | PathLike[str] | None = DEFAULT_UNIX_SOCKET_PATH,
        timeout: int | float | None = DEFAULT_TIMEOUT,
    ) -> None:
        """
        Create a new UnixSocketConnection instance.

        Args:
            path: Path to the socket. Default is "/run/gvmd/gvmd.sock".
            timeout: Timeout in seconds for the connection. Default is 60 seconds.
        """
        super().__init__(timeout=timeout)

        self.path = (
            fspath(path) if path is not None else DEFAULT_UNIX_SOCKET_PATH
        )

    def connect(self) -> None:
        """Connect to the UNIX socket"""
        self._socket = socketlib.socket(
            socketlib.AF_UNIX, socketlib.SOCK_STREAM
        )
        self._socket.settimeout(self._timeout)
        try:
            self._socket.connect(self.path)
        except FileNotFoundError:
            raise GvmError(f"Socket {self.path} does not exist") from None
        except ConnectionError as e:
            raise GvmError(
                f"Could not connect to socket {self.path}. Error was {e}"
            ) from None



# SPDX-FileCopyrightText: 2023-2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.entities.alerts import (
    GmpCloneAlertTestMixin,
    GmpCreateAlertTestMixin,
    GmpDeleteAlertTestMixin,
    GmpGetAlertsTestMixin,
    GmpGetAlertTestMixin,
    GmpModifyAlertTestMixin,
    GmpTestAlertTestMixin,
    GmpTriggerAlertTestMixin,
)
from ...gmpv227 import GMPTestCase


class GMPCloneAlertTestCase(GmpCloneAlertTestMixin, GMPTestCase):
    pass


class GMPCreateAlertTestCase(GmpCreateAlertTestMixin, GMPTestCase):
    pass


class GMPDeleteAlertTestCase(GmpDeleteAlertTestMixin, GMPTestCase):
    pass


class GMPGetAlertTestCase(GmpGetAlertTestMixin, GMPTestCase):
    pass


class GMPGetAlertsTestCase(GmpGetAlertsTestMixin, GMPTestCase):
    pass


class GMPModifyAlertTestCase(GmpModifyAlertTestMixin, GMPTestCase):
    pass


class GMPTestAlertTestCase(GmpTestAlertTestMixin, GMPTestCase):
    pass


class GMPTriggerAlertTestCase(GmpTriggerAlertTestMixin, GMPTestCase):
    pass



#  SPDX-FileCopyrightText: 2025 Greenbone AG
#
#  SPDX-License-Identifier: GPL-3.0-or-later
#
# SPDX-License-Identifier: GPL-3.0-or-later


from gvm.errors import RequiredArgument
from gvm.protocols.core import Request
from gvm.protocols.gmp.requests._entity_id import EntityID
from gvm.utils import to_bool
from gvm.xml import XmlCommand


class AgentInstallers:
    @staticmethod
    def get_agent_installers(
        *,
        filter_string: str | None = None,
        filter_id: EntityID | None = None,
        trash: bool | None = None,
        details: bool | None = None,
    ) -> Request:
        """Request a list of agent installers

        Args:
            filter_string: Filter term to use for the query
            filter_id: UUID of an existing filter to use for the query
            trash: Whether to get the trashcan agent installers instead
            details: Whether to include extra details like tasks using this
                scanner
        """
        cmd = XmlCommand("get_agent_installers")
        cmd.add_filter(filter_string, filter_id)

        if trash is not None:
            cmd.set_attribute("trash", to_bool(trash))

        if details is not None:
            cmd.set_attribute("details", to_bool(details))

        return cmd

    @classmethod
    def get_agent_installer(cls, agent_installer_id: EntityID) -> Request:
        """Request a single agent installer

        Args:
            agent_installer_id: UUID of an existing agent installer
        """
        if not agent_installer_id:
            raise RequiredArgument(
                function=cls.get_agent_installer.__name__,
                argument="agent_installer_id",
            )

        cmd = XmlCommand("get_agent_installers")
        cmd.set_attribute("agent_installer_id", str(agent_installer_id))

        # for single entity always request all details
        cmd.set_attribute("details", "1")

        return cmd

    @classmethod
    def get_agent_installer_file(cls, agent_installer_id: EntityID) -> Request:
        """Request a single agent installer

        Args:
            agent_installer_id: UUID of an existing agent installer
        """
        if not agent_installer_id:
            raise RequiredArgument(
                function=cls.get_agent_installer.__name__,
                argument="agent_installer_id",
            )

        cmd = XmlCommand("get_agent_installer_file")
        cmd.set_attribute("agent_installer_id", str(agent_installer_id))

        return cmd



# SPDX-FileCopyrightText: 2019-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

import unittest

from gvm.errors import InvalidArgument
from gvm.protocols.gmp.requests.v224 import HelpFormat


class GetHelpFormatFromStringTestCase(unittest.TestCase):
    def test_invalid(self):
        with self.assertRaises(InvalidArgument):
            HelpFormat.from_string("foo")

    def test_none_or_empty(self):
        ct = HelpFormat.from_string(None)
        self.assertIsNone(ct)
        ct = HelpFormat.from_string("")
        self.assertIsNone(ct)

    def test_task_run_status_changed(self):
        ct = HelpFormat.from_string("HtMl")
        self.assertEqual(ct, HelpFormat.HTML)

    def test_new_secinfo_arrived(self):
        ct = HelpFormat.from_string("rNc")
        self.assertEqual(ct, HelpFormat.RNC)

    def test_updated_secinfo_arrived(self):
        ct = HelpFormat.from_string("tExT")
        self.assertEqual(ct, HelpFormat.TEXT)

    def test_ticket_received(self):
        ct = HelpFormat.from_string("XmL")
        self.assertEqual(ct, HelpFormat.XML)


if __name__ == "__main__":
    unittest.main()



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
GMP Request implementations for GMP version 22.7.
"""

from gvm.protocols.gmp.requests.v227._scanners import Scanners, ScannerType

from .._entity_id import EntityID
from .._version import Version
from ..v226 import (
    Aggregates,
    AggregateStatistic,
    AlertCondition,
    AlertEvent,
    AlertMethod,
    Alerts,
    AliveTest,
    AuditReports,
    Audits,
    Authentication,
    CertBundAdvisories,
    Cpes,
    CredentialFormat,
    Credentials,
    CredentialType,
    Cves,
    DfnCertAdvisories,
    EntityType,
    Feed,
    FeedType,
    Filters,
    FilterType,
    Groups,
    Help,
    HelpFormat,
    Hosts,
    HostsOrdering,
    InfoType,
    Notes,
    Nvts,
    OperatingSystems,
    Overrides,
    Permissions,
    PermissionSubjectType,
    Policies,
    PortLists,
    PortRangeType,
    ReportConfigParameter,
    ReportConfigs,
    ReportFormats,
    ReportFormatType,
    Reports,
    ResourceNames,
    ResourceType,
    Results,
    Roles,
    ScanConfigs,
    Schedules,
    SecInfo,
    Severity,
    SnmpAuthAlgorithm,
    SnmpPrivacyAlgorithm,
    SortOrder,
    SystemReports,
    Tags,
    Targets,
    Tasks,
    Tickets,
    TicketStatus,
    TLSCertificates,
    TrashCan,
    UserAuthType,
    Users,
    UserSettings,
    Vulnerabilities,
)

__all__ = (
    "AggregateStatistic",
    "Aggregates",
    "AlertCondition",
    "AlertEvent",
    "AlertMethod",
    "Alerts",
    "AliveTest",
    "AuditReports",
    "Audits",
    "Authentication",
    "CertBundAdvisories",
    "Cpes",
    "CredentialFormat",
    "CredentialType",
    "Credentials",
    "Cves",
    "DfnCertAdvisories",
    "EntityID",
    "EntityType",
    "Feed",
    "FeedType",
    "FilterType",
    "Filters",
    "Groups",
    "Help",
    "HelpFormat",
    "Hosts",
    "HostsOrdering",
    "InfoType",
    "Notes",
    "Nvts",
    "OperatingSystems",
    "Overrides",
    "PermissionSubjectType",
    "Permissions",
    "Policies",
    "PortLists",
    "PortRangeType",
    "ReportConfigParameter",
    "ReportConfigs",
    "ReportFormatType",
    "ReportFormats",
    "Reports",
    "ResourceNames",
    "ResourceType",
    "Results",
    "Roles",
    "ScanConfigs",
    "ScannerType",
    "Scanners",
    "Schedules",
    "SecInfo",
    "Severity",
    "SnmpAuthAlgorithm",
    "SnmpPrivacyAlgorithm",
    "SortOrder",
    "SystemReports",
    "TLSCertificates",
    "Tags",
    "Targets",
    "Tasks",
    "TicketStatus",
    "Tickets",
    "TrashCan",
    "UserAuthType",
    "UserSettings",
    "Users",
    "Version",
    "Vulnerabilities",
)



# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224 import Gmpv224TestCase
from .overrides import (
    GmpCloneOverrideTestMixin,
    GmpCreateOverrideTestMixin,
    GmpDeleteOverrideTestMixin,
    GmpGetOverridesTestMixin,
    GmpGetOverrideTestMixin,
    GmpModifyOverrideTestMixin,
)


class Gmpv224CloneOverrideTestCase(GmpCloneOverrideTestMixin, Gmpv224TestCase):
    pass


class Gmpv224CreateOverrideTestCase(
    GmpCreateOverrideTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224DeleteOverrideTestCase(
    GmpDeleteOverrideTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224GetOverrideTestCase(GmpGetOverrideTestMixin, Gmpv224TestCase):
    pass


class Gmpv224GetOverridesTestCase(GmpGetOverridesTestMixin, Gmpv224TestCase):
    pass


class Gmpv224ModifyOverrideTestCase(
    GmpModifyOverrideTestMixin, Gmpv224TestCase
):
    pass



# SPDX-FileCopyrightText: 2023-2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv226.entities.resourcenames import (
    GmpGetResourceNamesListTestMixin,
    GmpGetResourceNameTestMixin,
)
from ...gmpv227 import GMPTestCase


class GMPGetResourceNamesListTestCase(
    GmpGetResourceNamesListTestMixin, GMPTestCase
):
    pass


class GMPGetResourceNameTestCase(GmpGetResourceNameTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpCreateScanConfigTestMixin:
    def test_create_scan_config(self):
        self.gmp.create_scan_config("a1", "foo")

        self.connection.send.has_been_called_with(
            b"<create_config>"
            b"<copy>a1</copy>"
            b"<name>foo</name>"
            b"<usage_type>scan</usage_type>"
            b"</create_config>"
        )

    def test_create_scan_config_with_comment(self):
        self.gmp.create_scan_config("a1", "foo", comment="comment")

        self.connection.send.has_been_called_with(
            b"<create_config>"
            b"<comment>comment</comment>"
            b"<copy>a1</copy>"
            b"<name>foo</name>"
            b"<usage_type>scan</usage_type>"
            b"</create_config>"
        )

    def test_create_scan_config_missing_scan_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_scan_config(config_id="", name="foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.create_scan_config(config_id=None, name="foo")

    def test_create_scan_config_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_scan_config(config_id="c1", name=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.create_scan_config(config_id="c1", name="")
